define(
//begin v1.x content
({
	"saveLabel": "Lagre",
	"saveSettingLabelOn": "Angi intervall for automatisk lagring...",
	"saveSettingLabelOff": "Slå av automatisk lagring",
	"saveSettingdialogTitle": "Automatisk lagring",
	"saveSettingdialogDescription": "Definer intervall for automatisk lagring",
	"saveSettingdialogParamName": "Intervall for automatisk lagring",
	"saveSettingdialogParamLabel": "min",
	"saveSettingdialogButtonOk": "Angi intervall",
	"saveSettingdialogButtonCancel": "Avbryt",
	"saveMessageSuccess": "Lagret klokken ${0}",
	"saveMessageFail": "Mislykket lagring klokken ${0}"
})
//end v1.x content
);
